import { i18n } from '@/i18n'
import { percentageDiff, setDailyPRNG, shuffle } from '@/utils'

import { numberOfGamesSinceStart, operations, result } from './game-state'
import { showToast } from './toast-manager'

const squareSymbols = ['🟦', '🟨', '🟫', '🟧', '🟥', '🟩', '🟪']
const roundSymbols = ['🔵', '🟡', '🟤', '🟠', '🔴', '🟢', '🟣']

export function shuffleSymbols(): void {
  setDailyPRNG()
  shuffle(squareSymbols)
  shuffle(roundSymbols)
}

function getSharingText(): string {
  console.log(squareSymbols)
  console.log(roundSymbols)
  // × ÷ + -
  const endResult = operations[operations.length - 1].result?.value ?? 0

  const lines: string[] = []
  for (const op of operations) {
    if (op.left && !op.left.symbol) {
      op.left.symbol = op.left.original
        ? squareSymbols.pop()
        : roundSymbols.pop()
    }
    if (op.right && !op.right.symbol) {
      op.right.symbol = op.right.original
        ? squareSymbols.pop()
        : roundSymbols.pop()
    }
    if (op.result && !op.result.symbol) {
      op.result.symbol = roundSymbols.pop()
    }
  }
  for (const op of operations) {
    lines.push(
      `${op.left?.symbol} ${op.operator} ${op.right?.symbol} = ${op.result?.value === endResult ? endResult : op.result?.symbol}`,
    )
  }

  return `N0mbers #${numberOfGamesSinceStart()}

${lines.join('\n')} ${result.value === endResult ? '✔' : '❌'}

https://n0mbers.scambier.xyz`
}

export function toClipboard(): void {
  navigator.clipboard.writeText(getSharingText())
  showToast(i18n.global.t('copiedInClipboard'), 3000)
}